@@ -55,7 +55,7 @@ pick! {
   }
 }
 
-int_uint_consts!(i8, 16, i8x16, i8x16, i8a16, const_i8_as_i8x16, 128);
+int_uint_consts!(i8, 16, i8x16, 128);
 
 unsafe impl Zeroable for i8x16 {}
 unsafe impl Pod for i8x16 {}
@@ -387,8 +387,8 @@ impl CmpLt for i8x16 {
 impl i8x16 {
   #[inline]
   #[must_use]
-  pub fn new(array: [i8; 16]) -> Self {
-    Self::from(array)
+  pub const fn new(array: [i8; 16]) -> Self {
+    unsafe { core::intrinsics::transmute(array) }
   }
 
   /// converts `i16` to `i8`, saturating values that are too large
@@ -700,7 +700,8 @@ impl i8x16 {
   /// `rhs`.
   ///
   /// * Index values in the range `[0, 15]` select the i-th element of `self`.
-  /// * Index values that are out of range will cause that output lane to be `0`.
+  /// * Index values that are out of range will cause that output lane to be
+  ///   `0`.
   #[inline]
   pub fn swizzle(self, rhs: i8x16) -> i8x16 {
     pick! {
@@ -727,7 +728,8 @@ impl i8x16 {
     }
   }
 
-  /// Works like [`swizzle`](Self::swizzle) with the following additional details
+  /// Works like [`swizzle`](Self::swizzle) with the following additional
+  /// details
   ///
   /// * Indices in the range `[0, 15]` will select the i-th element of `self`.
   /// * If the high bit of any index is set (meaning that the index is
