@@ -1,3 +1,5 @@
+use core::f64;
+
 use wide::*;
 
 use bytemuck::*;
@@ -183,6 +185,22 @@ fn impl_f64x4_abs() {
   assert_eq!(expected, actual);
 }
 
+#[test]
+fn impl_f64x4_floor() {
+  let a = f64x4::from([-1.1, 60.9, 1.1, f64::INFINITY]);
+  let expected = f64x4::from([-2.0, 60.0, 1.0, f64::INFINITY]);
+  let actual = a.floor();
+  assert_eq!(expected, actual);
+}
+
+#[test]
+fn impl_f64x4_ceil() {
+  let a = f64x4::from([-1.1, 60.9, 1.1, f64::NEG_INFINITY]);
+  let expected = f64x4::from([-1.0, 61.0, 2.0, f64::NEG_INFINITY]);
+  let actual = a.ceil();
+  assert_eq!(expected, actual);
+}
+
 #[test]
 fn impl_f64x4_fast_max() {
   let a = f64x4::from([1.0, 5.0, 3.0, -0.0]);
@@ -709,3 +727,21 @@ fn impl_f64x4_sum() {
   let duration = now.elapsed().as_micros();
   println!("Time take {} {}us", sum2, duration);
 }
+
+#[test]
+fn impl_f64x4_from_i32x4() {
+  let i = i32x4::from([1, 2, 3, 4]);
+  let f = f64x4::from([1.0, 2.0, 3.0, 4.0]);
+  assert_eq!(f64x4::from(i), f);
+  assert_eq!(f64x4::from_i32x4(i), f);
+}
+
+#[cfg(feature = "serde")]
+#[test]
+fn impl_f64x4_ser_de_roundtrip() {
+  let serialized =
+    bincode::serialize(&f64x4::ZERO).expect("serialization failed");
+  let deserialized =
+    bincode::deserialize(&serialized).expect("deserializaion failed");
+  assert_eq!(f64x4::ZERO, deserialized);
+}
